@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2010-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2010-2016 Horde LLC
+ * @copyright 2010-2017 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Turba
  */
@@ -19,7 +19,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org?
  * @category  Horde
- * @copyright 2010-2016 Horde LLC
+ * @copyright 2010-2017 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Turba
  */
@@ -57,7 +57,7 @@ class Turba_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (4.2.18)';
+    public $version = 'H5 (4.2.20)';
 
     /**
      */
@@ -344,6 +344,11 @@ class Turba_Application extends Horde_Registry_Application
      */
     public function removeUserData($user)
     {
+        $err = sprintf(
+            _("There was an error removing an address book for %s"),
+            $user
+        );
+
         /* We need a clean copy of the $cfgSources array here.*/
         $cfgSources = Turba::availableSources();
         foreach ($cfgSources as $sourceId => $source) {
@@ -355,6 +360,7 @@ class Turba_Application extends Horde_Registry_Application
                         ->create($source, $sourceId);
                 } catch (Turba_Exception $e) {
                     Horde::log($e, 'ERR');
+                    continue;
                 }
 
                 try {
@@ -363,7 +369,7 @@ class Turba_Application extends Horde_Registry_Application
                     continue;
                 } catch (Turba_Exception $e) {
                     Horde::log($e, 'ERR');
-                    throw new Turba_Exception(sprintf(_("There was an error removing an address book for %s"), $user));
+                    throw new Turba_Exception($err);
                 }
             }
         }
@@ -376,15 +382,22 @@ class Turba_Application extends Horde_Registry_Application
         $turba_shares = $GLOBALS['injector']->getInstance('Turba_Shares');
         $shares = $turba_shares->listShares(
             $user,
-            array('attributes' => $user));
+            array('attributes' => $user)
+        );
 
         // Look for the deleted user's shares and remove them
+        $sources = Turba::getConfigFromShares(
+            $cfgSources,
+            true,
+            array('shares' => $shares, 'auth_user' => $user)
+        );
+
         foreach ($shares as $share) {
-            $config = Turba::getSourceFromShare($share);
+            $config = $sources[$share->getName()];
             try {
                 $driver = $GLOBALS['injector']
                     ->getInstance('Turba_Factory_Driver')
-                    ->create($config, $share->getName());
+                    ->create($config, $share->getName(), $sources);
             } catch (Turba_Exception $e) {
                 continue;
             }
@@ -395,7 +408,7 @@ class Turba_Application extends Horde_Registry_Application
                 continue;
             } catch (Turba_Exception $e) {
                 Horde::log($e, 'ERR');
-                throw new Turba_Exception(sprintf(_("There was an error removing an address book for %s"), $user));
+                throw new Turba_Exception($err);
             }
         }
 
@@ -408,7 +421,7 @@ class Turba_Application extends Horde_Registry_Application
             }
         } catch (Horde_Share_Exception $e) {
             Horde::log($e, 'ERR');
-            throw new Turba_Exception(sprintf(_("There was an error removing an address book for %s"), $user));
+            throw new Turba_Exception($err);
         }
     }
 
